uniform sampler2D baseMap;
uniform float fSpecularPower;

varying vec2 Texcoord;
varying float fog;
vec4 col;

varying vec3 ViewDirection;
varying vec3 LightDirection;
varying vec3 Normal;

void main(void) {

   vec4 fvAmbient = vec4(0.1686, 0.1686, 0.1686, 1.0);
   vec4 fvSpecular = vec4(0.8902, 0.8902, 0.8902, 1.0);
   vec4 fvDiffuse = vec4(0.3863, 0.3863, 0.3863, 1.0);

   vec3  fvLightDirection = normalize( LightDirection );
   vec3  fvNormal         = normalize( Normal );
   float fNDotL           = dot( fvNormal, fvLightDirection );

   vec3  fvReflection     = normalize( ( ( 2.0 * fvNormal ) * fNDotL ) - fvLightDirection );
   vec3  fvViewDirection  = normalize( ViewDirection );
   float fRDotV           = max( 0.0, dot( fvReflection, fvViewDirection ) );

   vec4 tex = texture2D( baseMap, Texcoord );

   vec4  fvTotalAmbient   = fvAmbient;
   vec4  fvTotalDiffuse   = fNDotL * tex; 
   vec4  fvTotalSpecular  = fvSpecular * ( pow( fRDotV, fSpecularPower ) );

   col = ( fvTotalAmbient + fvTotalDiffuse + fvTotalSpecular);

   gl_FragColor = mix(vec4(gl_Fog.color), col, fog);

}
